==> haskell-monad-parallel-0.8-1-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-monad-parallel.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 monad-parallel
version:              0.8
visibility:           public
id:                   monad-parallel-0.8-8kLAO8TA1pMK1pL1MycH0s
key:                  monad-parallel-0.8-8kLAO8TA1pMK1pL1MycH0s
license:              BSD-3-Clause
copyright:            (c) 2010-2022 Mario Blazevic
maintainer:           blamario@yahoo.com
author:               Mario Blazevic
homepage:             https://hub.darcs.net/blamario/SCC.wiki/
synopsis:             Parallel execution of monadic computations
description:
    This package defines classes of monads that can perform multiple executions in parallel and combine their results. For
    any monad that'\''s an instance of the class, the package re-implements a subset of the Control.Monad interface, but with
    parallel execution.

category:             Control, Monads
abi:                  11b47b518b719785dec0f024da70f570
exposed:              True
exposed-modules:      Control.Monad.Parallel
import-dirs:          /usr/lib/ghc-9.0.2/site-local/monad-parallel-0.8
library-dirs:         /usr/lib/ghc-9.0.2/site-local/monad-parallel-0.8
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.2/monad-parallel-0.8
hs-libraries:         HSmonad-parallel-0.8-8kLAO8TA1pMK1pL1MycH0s
depends:
    base-4.15.1.0 parallel-3.2.2.0-D2aleEa2VnPBr164BdKnms
    transformers-0.5.6.2
    transformers-compat-0.7.1-5G5J9BcZIFIGkjABObiUpP

haddock-interfaces:
    /usr/share/doc/haskell-monad-parallel/html/monad-parallel.haddock

haddock-html:         /usr/share/doc/haskell-monad-parallel/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-monad-parallel-0.8-2-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-monad-parallel.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 monad-parallel
version:              0.8
visibility:           public
id:                   monad-parallel-0.8-8PJISqW4eg7Lj5A3EjPsB4
key:                  monad-parallel-0.8-8PJISqW4eg7Lj5A3EjPsB4
license:              BSD-3-Clause
copyright:            (c) 2010-2022 Mario Blazevic
maintainer:           blamario@yahoo.com
author:               Mario Blazevic
homepage:             https://hub.darcs.net/blamario/SCC.wiki/
synopsis:             Parallel execution of monadic computations
description:
    This package defines classes of monads that can perform multiple executions in parallel and combine their results. For
    any monad that'\''s an instance of the class, the package re-implements a subset of the Control.Monad interface, but with
    parallel execution.

category:             Control, Monads
abi:                  9600dbfe60e5c9e904d829eed8ee27d4
exposed:              True
exposed-modules:      Control.Monad.Parallel
import-dirs:          /usr/lib/ghc-9.0.2/site-local/monad-parallel-0.8
library-dirs:         /usr/lib/ghc-9.0.2/site-local/monad-parallel-0.8
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-monad-parallel
hs-libraries:         HSmonad-parallel-0.8-8PJISqW4eg7Lj5A3EjPsB4
depends:
    base-4.15.1.0 parallel-3.2.2.0-D2aleEa2VnPBr164BdKnms
    transformers-0.5.6.2
    transformers-compat-0.7.2-ZzSHjvD4flB2ChCq5TVbH

haddock-interfaces:
    /usr/share/doc/haskell-monad-parallel/html/monad-parallel.haddock

haddock-html:         /usr/share/doc/haskell-monad-parallel/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
